//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

#include <WSNdef.h>

#ifndef MSW

char* _WSNtitleString            ="titleString";
char* _WSNuserString             ="userString";
char* _WSNuserValue              ="userValue";
char* _WSNx                      ="x";
char* _WSNy                      ="y";
char* _WSNwidth                  ="width";
char* _WSNheight                 ="height";
char* _WSNshadowThickness        ="shadowThickness";
char* _WSNbackColor              ="backColor";
char* _WSNforeColor              ="foreColor";
char* _WSNtopShadowColor         ="topShadowColor";
char* _WSNbottomShadowColor      ="bottomShadowColor";
char* _WSNshadowType             ="shadowType";
char* _WSNvis                    ="vis";
char* _WSNdet                    ="det";
char* _WSNlabelString            ="labelString";
char* _WSNfont                   ="font";
char* _WSNfontName               ="fontName";
char* _WSNtitleBar               ="titleBar";
char* _WSNtwinBlink              ="twinBlink";
char* _WSNblinkColor             ="blinkColor";
char* _WSNblinkRefreshing        ="blinkRefreshing";
char* _WSNpixmapStyle            ="pixmapStyle";
char* _WSNlabelPixmap            ="labelPixmap";
char* _WSNenableFep                ="enableFep";
char* _WSNinterCur               ="interCur";
char* _WSNinterval               ="interval";
char* _WSNcont                   ="cont";
char* _WSNrunning                ="running";
char* _WSNextension              ="extension";
char* _WSNmaxLength              ="maxLength";
char* _WSNworkWidth              ="workWidth";
char* _WSNworkHeight             ="workHeight";
char* _WSNbarValue               ="barValue";
char* _WSNvbarValue              ="vbarValue";
char* _WSNhbarValue              ="hbarValue";
char* _WSNhbarVisible            ="hbarVisible";
char* _WSNvbarVisible            ="vbarVisible";
char* _WSNworkBackColor          ="workBackColor";
char* _WSNbarThickness           ="barThickness";
char* _WSNincrement              ="increment";
char* _WSNpageIncrement          ="pageIncrement";
char* _WSNsliderSize             ="sliderSize";
char* _WSNvalue                  ="value";
char* _WSNmaximum                ="maximum";
char* _WSNorientation            ="orientation";
char* _WSNbackPixmap             ="backPixmap";
char* _WSNcolumns                ="columns";
char* _WSNcursorPos              ="cursorPos";
char* _WSNmenuItems              ="menuItems";
char* _WSNmenuItemHeight         ="menuItemHeight";
char* _WSNbarShadowColor         ="barShadowColor";
char* _WSNupward                 ="upward";
char* _WSNdownward               ="downward";
char* _WSNleftward               ="leftward";
char* _WSNrightward              ="rightward";
char* _WSNreturn                 ="return";
char* _WSNtab                    ="tab";
char* _WSNbacktab                ="backtab";
char* _WSNenableFocusMove        ="enableFocusMove";
char* _WSNclient                 ="client";
char* _WSNselectReset            ="selectReset";
char* _WSNselectString           ="selectString";
char* _WSNselectColor            ="selectColor";
char* _WSNselectForeColor        ="selectForeColor";
char* _WSNselectPixmap           ="selectPixmap";
char* _WSNindicatorPixmap        ="indicatorPixmap";
char* _WSNindicatorColor         ="indicatorColor";
char* _WSNindicatorOn            ="indicatorOn";
char* _WSNindicatorType          ="indicatorType";
char* _WSNindicatorSize          ="indicatorSize";
char* _WSNgroup                  ="group";
char* _WSNid                     ="id";
char* _WSNunique                 ="unique";
char* _WSNscrollWidth            ="scrollWidth";
char* _WSNscrollHeight           ="scrollHeight";
char* _WSNtitleHeight            ="titleHeight";
char* _WSNfillSpace              ="fillSpace";
char* _WSNifieldSkipMode         ="ifieldSkipMode";
char* _WSNcursorAdjust           ="cursorAdjust";
char* _WSNdateFormat             ="dateFormat";
char* _WSNweekFormat             ="weekFormat";
char* _WSNclockFormat            ="clockFormat";
char* _WSNsecondOn               ="secondOn";
char* _WSNdirName                ="dirName";
char* _WSNfileName               ="fileName";
char* _WSNmaskFileName           ="maskFileName";
char* _WSNreplyHandler           ="replyHandler";
char* _WSNdefaultPosition        ="defaultPosition";
char* _WSNlineWidth              ="lineWidth";
char* _WSNblinkType              ="blinkType";
char* _WSNpushPixmap             ="pushPixmap";
char* _WSNblinkPixmap            ="blinkPixmap";
char* _WSNmarginTop              ="marginTop";
char* _WSNmarginBottom           ="marginBottom";
char* _WSNmarginLeft             ="marginLeft";
char* _WSNmarginRight            ="marginRight";
char* _WSNalignmentH             ="alignmentH";
char* _WSNalignmentV             ="alignmentV";
char* _WSNalignment              ="alignment";
char* _WSNlineX                  ="lineX";
char* _WSNlineY                  ="lineY";
char* _WSNlineNum                ="lineNum";
char* _WSNvalue1                 ="value1";
char* _WSNvalue2                 ="value2";
char* _WSNlineType               ="lineType";
char* _WSNarrowDirection         ="arrowDirection";
char* _WSNblinkFlag              ="blinkFlag";
char* _WSNblinkRate              ="blinkRate";
char* _WSNstippled               ="stippled";
char* _WSNhatchPattern           ="hatchPattern";
char* _WSNhatchColor             ="hatchColor";
char* _WSNhatchBlinkColor        ="hatchBlinkColor";
char* _WSNbackColorFlag          ="backColorFlag";
char* _WSNbackBlinkColor         ="backBlinkColor";
char* _WSNreverseFlag            ="reverseFlag";
char* _WSNminimum                ="minimum";
char* _WSNangle1                 ="angle1";
char* _WSNangle2                 ="angle2";
char* _WSNarcType                ="arcType";
char* _WSNdragInterval           ="dragInterval";
char* _WSNindicatorShadow        ="indicatorShadow";
char* _WSNemboss                 ="emboss";
char* _WSNmouse                  ="mouse";
char* _WSNusePixmap              ="usePixmap";
char* _WSNenableInput            ="enableInput";
char* _WSNok          ="ok";
char* _WSNno          ="no";
char* _WSNcancel          ="cancel";
char* _WSNokString    ="okString";
char* _WSNnoString    ="noString";
char* _WSNcancelString    ="cancelString";
char* _WSNmodal       ="modal";
char* _WSNtype        ="type";
char* _WSNmaxHeight   ="maxHeight";
char* _WSNmultiSelect ="multiSelect";
char* _WSNreverseSelect ="reverseSelect";
char* _WSNmargin ="margin";
char* _WSNname ="name";
char* _WSNuseIcon ="useIcon";
char* _WSNiconPixmap ="iconPixmap";
char* _WSNvirtualScroll ="virtualScroll";
char* _WSNnoHatch ="noHatch";
char* _WSNselectDir ="selectDir";
char* _WSNgradation ="gradation";
char* _WSNgradationMargin ="gradationMargin";
char* _WSNshortcut ="shortcut";
char* _WSNreturnKeyFocus ="returnKeyFocus";
char* _WSNexit ="exit";
char* _WSNitemHeight ="itemHeight";
char* _WSNdata ="data";
char* _WSNdataSource ="dataSource";
char* _WSNdataSourceName ="dataSourceName";
char* _WSNanchorTop ="anchorTop";
char* _WSNanchorBottom ="anchorBottom";
char* _WSNanchorLeft ="anchorLeft";
char* _WSNanchorRight ="anchorRight";
char* _WSNanchorTopFlag ="anchorTopFlag";
char* _WSNanchorBottomFlag ="anchorBottomFlag";
char* _WSNanchorLeftFlag ="anchorLeftFlag";
char* _WSNanchorRightFlag ="anchorRightFlag";
char* _WSNflip ="flip";
char* _WSNframe ="frame";
char* _WSNformat ="format";
char* _WSNworkX ="workX";
char* _WSNworkY ="workY";
char* _WSNdisplayOnly ="displayOnly";
char* _WSNrefreshing ="refreshing";
char* _WSNvcolumns ="vcolumns";
char* _WSNhcolumns ="hcolumns";
char* _WSNseparator ="separator";
char* _WSNseparator2 ="separator2";
char* _WSNfit ="fit";
char* _WSNip ="ip";
char* _WSNport ="port";
char* _WSNtimeout ="timeout";
char* _WSNexport ="export";
char* _WSNusername ="username";
char* _WSNpassword ="password";
char* _WSNdbname ="dbname";
char* _WSNdsn ="dsn";
char* _WSNhostname ="hostname";
char* _WSNstatus ="status";
char* _WSNdbTableName ="dbTableName";
char* _WSNshowItem ="showItem";
char* _WSNsortItems ="sortItems";
char* _WSNsort ="sort";
char* _WSNitem ="item";
char* _WSNfilter ="filter";
char* _WSNpixmapOverlap ="pixmapOverlap";
char* _WSNkeepPixmapCache ="keepPixmapCache";
char* _WSNautoLineFeeding ="autoLineFeeding";

#else //MSW

char* _WSNtitleString            (){ return "titleString";};
char* _WSNuserString             (){ return "userString";};
char* _WSNuserValue              (){ return "userValue";};
char* _WSNx                      (){ return "x";};
char* _WSNy                      (){ return "y";};
char* _WSNwidth                  (){ return "width";};
char* _WSNheight                 (){ return "height";};
char* _WSNshadowThickness        (){ return "shadowThickness";};
char* _WSNbackColor              (){ return "backColor";};
char* _WSNforeColor              (){ return "foreColor";};
char* _WSNtopShadowColor         (){ return "topShadowColor";};
char* _WSNbottomShadowColor      (){ return "bottomShadowColor";};
char* _WSNshadowType             (){ return "shadowType";};
char* _WSNvis                    (){ return "vis";};
char* _WSNdet                    (){ return "det";};
char* _WSNlabelString            (){ return "labelString";};
char* _WSNfont                   (){ return "font";};
char* _WSNfontName               (){ return "fontName";};
char* _WSNtitleBar               (){ return "titleBar";};
char* _WSNtwinBlink              (){ return "twinBlink";};
char* _WSNblinkColor             (){ return "blinkColor";};
char* _WSNblinkRefreshing        (){ return "blinkRefreshing";};
char* _WSNpixmapStyle            (){ return "pixmapStyle";};
char* _WSNlabelPixmap            (){ return "labelPixmap";};
char* _WSNenableFep                (){ return "enableFep";};
char* _WSNinterCur               (){ return "interCur";};
char* _WSNinterval               (){ return "interval";};
char* _WSNcont                   (){ return "cont";};
char* _WSNrunning                (){ return "running";};
char* _WSNextension              (){ return "extension";};
char* _WSNmaxLength              (){ return "maxLength";};
char* _WSNworkWidth              (){ return "workWidth";};
char* _WSNworkHeight             (){ return "workHeight";};
char* _WSNbarValue               (){ return "barValue";};
char* _WSNvbarValue              (){ return "vbarValue";};
char* _WSNhbarValue              (){ return "hbarValue";};
char* _WSNhbarVisible            (){ return "hbarVisible";};
char* _WSNvbarVisible            (){ return "vbarVisible";};
char* _WSNworkBackColor          (){ return "workBackColor";};
char* _WSNbarThickness           (){ return "barThickness";};
char* _WSNincrement              (){ return "increment";};
char* _WSNpageIncrement          (){ return "pageIncrement";};
char* _WSNsliderSize             (){ return "sliderSize";};
char* _WSNvalue                  (){ return "value";};
char* _WSNmaximum                (){ return "maximum";};
char* _WSNorientation            (){ return "orientation";};
char* _WSNbackPixmap             (){ return "backPixmap";};
char* _WSNcolumns                (){ return "columns";};
char* _WSNcursorPos              (){ return "cursorPos";};
char* _WSNmenuItems              (){ return "menuItems";};
char* _WSNmenuItemHeight         (){ return "menuItemHeight";};
char* _WSNbarShadowColor         (){ return "barShadowColor";};
char* _WSNupward                 (){ return "upward";};
char* _WSNdownward               (){ return "downward";};
char* _WSNleftward               (){ return "leftward";};
char* _WSNrightward              (){ return "rightward";};
char* _WSNreturn                 (){ return "return";};
char* _WSNtab                    (){ return "tab";};
char* _WSNbacktab                (){ return "backtab";};
char* _WSNenableFocusMove        (){ return "enableFocusMove";};
char* _WSNclient                 (){ return "client";};
char* _WSNselectReset            (){ return "selectReset";};
char* _WSNselectString           (){ return "selectString";};
char* _WSNselectColor            (){ return "selectColor";};
char* _WSNselectForeColor        (){ return "selectForeColor";};
char* _WSNselectPixmap           (){ return "selectPixmap";};
char* _WSNindicatorPixmap        (){ return "indicatorPixmap";};
char* _WSNindicatorColor         (){ return "indicatorColor";};
char* _WSNindicatorOn            (){ return "indicatorOn";};
char* _WSNindicatorType          (){ return "indicatorType";};
char* _WSNindicatorSize          (){ return "indicatorSize";};
char* _WSNgroup                  (){ return "group";};
char* _WSNid                     (){ return "id";};
char* _WSNunique                 (){ return "unique";};
char* _WSNscrollWidth            (){ return "scrollWidth";};
char* _WSNscrollHeight           (){ return "scrollHeight";};
char* _WSNtitleHeight            (){ return "titleHeight";};
char* _WSNfillSpace              (){ return "fillSpace";};
char* _WSNifieldSkipMode         (){ return "ifieldSkipMode";};
char* _WSNcursorAdjust           (){ return "cursorAdjust";};
char* _WSNdateFormat             (){ return "dateFormat";};
char* _WSNweekFormat             (){ return "weekFormat";};
char* _WSNclockFormat            (){ return "clockFormat";};
char* _WSNsecondOn               (){ return "secondOn";};
char* _WSNdirName                (){ return "dirName";};
char* _WSNfileName               (){ return "fileName";};
char* _WSNmaskFileName           (){ return "maskFileName";};
char* _WSNreplyHandler           (){ return "replyHandler";};
char* _WSNdefaultPosition        (){ return "defaultPosition";};
char* _WSNlineWidth              (){ return "lineWidth";};
char* _WSNblinkType              (){ return "blinkType";};
char* _WSNpushPixmap             (){ return "pushPixmap";};
char* _WSNblinkPixmap            (){ return "blinkPixmap";};
char* _WSNmarginTop              (){ return "marginTop";};
char* _WSNmarginBottom           (){ return "marginBottom";};
char* _WSNmarginLeft             (){ return "marginLeft";};
char* _WSNmarginRight            (){ return "marginRight";};
char* _WSNalignmentH             (){ return "alignmentH";};
char* _WSNalignmentV             (){ return "alignmentV";};
char* _WSNalignment              (){ return "alignment";};
char* _WSNlineX                  (){ return "lineX";};
char* _WSNlineY                  (){ return "lineY";};
char* _WSNlineNum                (){ return "lineNum";};
char* _WSNvalue1                 (){ return "value1";};
char* _WSNvalue2                 (){ return "value2";};
char* _WSNlineType               (){ return "lineType";};
char* _WSNarrowDirection         (){ return "arrowDirection";};
char* _WSNblinkFlag              (){ return "blinkFlag";};
char* _WSNblinkRate              (){ return "blinkRate";};
char* _WSNstippled               (){ return "stippled";};
char* _WSNhatchPattern           (){ return "hatchPattern";};
char* _WSNhatchColor             (){ return "hatchColor";};
char* _WSNhatchBlinkColor        (){ return "hatchBlinkColor";};
char* _WSNbackColorFlag          (){ return "backColorFlag";};
char* _WSNbackBlinkColor         (){ return "backBlinkColor";};
char* _WSNreverseFlag            (){ return "reverseFlag";};
char* _WSNminimum                (){ return "minimum";};
char* _WSNangle1                 (){ return "angle1";};
char* _WSNangle2                 (){ return "angle2";};
char* _WSNarcType                (){ return "arcType";};
char* _WSNdragInterval           (){ return "dragInterval";};
char* _WSNindicatorShadow        (){ return "indicatorShadow";};
char* _WSNemboss                 (){ return "emboss";};
char* _WSNmouse                  (){ return "mouse";};
char* _WSNusePixmap              (){ return "usePixmap";};
char* _WSNenableInput            (){ return "enableInput";};
char* _WSNok          (){ return "ok";};
char* _WSNno          (){ return "no";};
char* _WSNcancel          (){ return "cancel";};
char* _WSNokString    (){ return "okString";};
char* _WSNnoString    (){ return "noString";};
char* _WSNcancelString    (){ return "cancelString";};
char* _WSNmodal       (){ return "modal";};
char* _WSNtype        (){ return "type";};
char* _WSNmaxHeight   (){ return "maxHeight";};
char* _WSNmultiSelect (){ return "multiSelect";};
char* _WSNreverseSelect (){ return "reverseSelect";};
char* _WSNmargin (){ return "margin";};
char* _WSNname (){ return "name";};
char* _WSNuseIcon (){ return "useIcon";};
char* _WSNiconPixmap (){ return "iconPixmap";};
char* _WSNvirtualScroll (){ return "virtualScroll";};
char* _WSNnoHatch (){ return "noHatch";};
char* _WSNselectDir (){ return "selectDir";};
char* _WSNgradation (){ return "gradation";};
char* _WSNgradationMargin (){ return "gradationMargin";};
char* _WSNshortcut (){ return "shortcut";};
char* _WSNreturnKeyFocus (){ return "returnKeyFocus";};
char* _WSNexit (){ return "exit";};
char* _WSNitemHeight (){ return "itemHeight";};
char* _WSNdata (){ return "data";};
char* _WSNdataSource (){ return "dataSource";};
char* _WSNdataSourceName (){ return "dataSourceName";};
char* _WSNanchorTop (){ return "anchorTop";};
char* _WSNanchorBottom (){ return "anchorBottom";};
char* _WSNanchorLeft (){ return "anchorLeft";};
char* _WSNanchorRight (){ return "anchorRight";};
char* _WSNanchorTopFlag (){ return "anchorTopFlag";};
char* _WSNanchorRightFlag (){ return "anchorRightFlag";};
char* _WSNanchorLeftFlag (){ return "anchorLeftFlag";};
char* _WSNanchorBottomFlag (){ return "anchorBottomFlag";};
char* _WSNflip             (){ return "flip";};
char* _WSNframe             (){ return "frame";};
char* _WSNformat             (){ return "format";};
char* _WSNworkX             (){ return "workX";};
char* _WSNworkY             (){ return "workY";};
char* _WSNdisplayOnly       (){ return "displayOnly";};
char* _WSNrefreshing        (){ return "refreshing";};
char* _WSNvcolumns        (){ return "vcolumns";};
char* _WSNhcolumns        (){ return "hcolumns";};
char* _WSNseparator       (){ return "separator";};
char* _WSNseparator2       (){ return "separator2";};
char* _WSNfit       (){ return "fit";};
char* _WSNip       (){ return "ip";};
char* _WSNport     (){ return "port";};
char* _WSNtimeout     (){ return "timeout";};
char* _WSNexport     (){ return "export";};
char* _WSNusername     (){ return "username";};
char* _WSNpassword     (){ return "password";};
char* _WSNdbname     (){ return "dbname";};
char* _WSNdsn     (){ return "dsn";};
char* _WSNhostname     (){ return "hostname";};
char* _WSNstatus     (){ return "status";};
char* _WSNdbTableName     (){ return "dbTableName";};
char* _WSNshowItem     (){ return "showItem";};
char* _WSNsortItems     (){ return "sortItems";};
char* _WSNsort     (){ return "sort";};
char* _WSNitem     (){ return "item";};
char* _WSNfilter     (){ return "filter";};
char* _WSNpixmapOverlap     (){ return "pixmapOverlap";};
char* _WSNkeepPixmapCache     (){ return "keepPixmapCache";};
char* _WSNautoLineFeeding     (){ return "autoLineFeeding";};

#endif //MSW
